@@ -46,6 +46,7 @@ extern FrameRate *uffr;
 extern FrameRate *jffr;
 extern int j_have_vfps;
 extern int max_mem;
+extern int no_resize;
 extern char *rc_file;
 extern char *smpte_font;
 
@@ -237,6 +238,7 @@ gboolean limit_height (gpointer data) {
 
 void minimize_height (void) {
 	gint width, height;
+	if (no_resize) return;
 	gtk_window_get_size (GTK_WINDOW(window1), &width, &height);
 	height=40;
 	gtk_window_resize(GTK_WINDOW(window1),width,height);
@@ -244,6 +246,8 @@ void minimize_height (void) {
 	gtk_idle_add(limit_height, NULL);
 #elif 0
 	g_timeout_add(1,limit_height,NULL);
+#else
+	limit_height(NULL);
 #endif
 }
 
