@@ -1,5 +1,6 @@
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <math.h>
 
 #include "gjack.h"
@@ -15,22 +16,12 @@
 extern GtkWidget *window1;
 void dothejack (gboolean onoff);
 
-void status_msg (char *msg) {
-	gchar *buf;
+void status_msg (const char *msg) {
 	guint context = 1;
 	GtkWidget *statusbar1;
-	size_t size;
-
 	statusbar1=lookup_widget(window1,"statusbar1");
-	size = 1+strlen(msg);
-	buf = malloc(size);
-	if (buf == NULL)
-		return;
-	
-	snprintf(buf, size, "%s", msg);
 	gtk_statusbar_pop(GTK_STATUSBAR(statusbar1), context);
-	gtk_statusbar_push(GTK_STATUSBAR(statusbar1), context,  buf);
-	free(buf);
+	gtk_statusbar_push(GTK_STATUSBAR(statusbar1), context,  msg);
 }
 
 
@@ -41,10 +32,9 @@ void status_printf (const char *format, ...) {
 
 	va_start(arglist, format);
 	text_size = vsnprintf(NULL, 0, format, arglist);
-	text = malloc(text_size);
-	if (text == NULL)
-		return;
-	vsnprintf(text, text_size, format, arglist);
+	text = malloc(text_size+1);
+	if (text == NULL) return;
+	vsnprintf(text, text_size+1, format, arglist);
 	va_end(arglist);
 	
 	status_msg(text);
